.. module:: bana.OpenMaya.MQuaternion

.. _openmaya_mquaternion:

OpenMaya.MQuaternion
====================

.. autosummary::
   :nosignatures:

   ~MQuaternion.__str__
   ~MQuaternion.bnGet


----

.. automethod:: MQuaternion.__str__
.. automethod:: MQuaternion.bnGet
